@@ -59,7 +59,7 @@ double invlogit(double p){
 
 //Initialize Xi coefficients. For Poisson and Binomial mixtures they are set equal to the mean of the cluster;
 //for empty clusters, they are set randomly to mean + error.
-void initGLMOneResLtnt12(unsigned long int s, int *Y, double *H, int n, int p, int ncomp, int nRespPars,
+void initGLMOneResLtnt1(unsigned long int s, int *Y, double *H, int n, int p, int ncomp, int nRespPars,
                          int *nmembers, int *compAlloc, double Xi[ncomp][nRespPars], double Ymean, int family){
     double sumhY1, sumhH;
     int i, h;
@@ -84,12 +84,13 @@ void initGLMOneResLtnt12(unsigned long int s, int *Y, double *H, int n, int p, i
                  if (family == 1) Xi[h][0] = exp(log(Ymean) + gsl_ran_gaussian(r,1.0));
                  if (family == 2) Xi[h][0] = invlogit(logit(Ymean) + gsl_ran_gaussian(r,1.0));
         }
+        if (family == 5) Xi[h][1] = 1.0; //for Generalized Poisson put second parameter equal to 1.0 i.e. equivalent to Poisson
     }
     gsl_rng_free(r);
 }
 
 //Initialize Xi coefficients for negative binomial and beta binomial mixtures
-void initGLMOneResLtnt34(unsigned long int s, int *Y, double *H, int n, int p, int ncomp, int nRespPars,
+void initGLMOneResLtnt2(unsigned long int s, int *Y, double *H, int n, int p, int ncomp, int nRespPars,
                          int *nmembers, int *compAlloc, double Xi[ncomp][nRespPars], int family){
     double sumhY1, sumhY2, sumhH;
     double Ybarh, Hbarh, Yvarh;
@@ -296,6 +297,7 @@ void calcGLMLimits(int *Y, double *H, int i, double *Xi, double *lower, double *
             else if (family == 2) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_binomial_P(Y[i]-1,Xi[0],(int) H[i]));
             else if (family == 3) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_negative_binomial_P(Y[i]-1,Xi[1]/(H[i]+Xi[1]),Xi[0]));
             else if (family == 4) *lower = gsl_cdf_ugaussian_Pinv(cdf_beta_binomial_P(H[i],Y[i]-1,Xi[0],Xi[1]));
+            else if (family == 5) *lower = gsl_cdf_ugaussian_Pinv(cdf_generalized_poisson_P2(Y[i]-1,H[i]*Xi[0],Xi[1]));
         }
         if (*lower < -lmt) *lower = -lmt;
         if (*lower > lmt) *lower = lmt;
@@ -303,6 +305,7 @@ void calcGLMLimits(int *Y, double *H, int i, double *Xi, double *lower, double *
         else if (family == 2) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_binomial_P(Y[i],Xi[0],(int) H[i]));
         else if (family == 3) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_negative_binomial_P(Y[i],Xi[1]/(H[i]+Xi[1]),Xi[0]));
         else if (family == 4) *upper = gsl_cdf_ugaussian_Pinv(cdf_beta_binomial_P(H[i],Y[i],Xi[0],Xi[1]));
+        else if (family == 5) *upper = gsl_cdf_ugaussian_Pinv(cdf_generalized_poisson_P2(Y[i],H[i]*Xi[0],Xi[1]));
         if (*upper < -lmt) *upper = -lmt;
         if (*upper > lmt) *upper = lmt;
 }
@@ -318,6 +321,7 @@ void calcGLMLimitsPred(double *H, int k, int i, double *Xi, double *lower, doubl
             else if (family == 2) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_binomial_P(k-1,Xi[0],(int) H[i]));
             else if (family == 3) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_negative_binomial_P(k-1,Xi[1]/(H[i]+Xi[1]),Xi[0]));
             else if (family == 4) *lower = gsl_cdf_ugaussian_Pinv(cdf_beta_binomial_P(H[i],k-1,Xi[0],Xi[1]));
+            else if (family == 5) *lower = gsl_cdf_ugaussian_Pinv(cdf_generalized_poisson_P2(k-1,H[i]*Xi[0],Xi[1]));
         }
         if (*lower < -lmt) *lower = -lmt;
         if (*lower > lmt) *lower = lmt;
@@ -325,6 +329,37 @@ void calcGLMLimitsPred(double *H, int k, int i, double *Xi, double *lower, doubl
         else if (family == 2) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_binomial_P(k,Xi[0],(int) H[i]));
         else if (family == 3) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_negative_binomial_P(k,Xi[1]/(H[i]+Xi[1]),Xi[0]));
         else if (family == 4) *upper = gsl_cdf_ugaussian_Pinv(cdf_beta_binomial_P(H[i],k,Xi[0],Xi[1]));
+        else if (family == 5) *upper = gsl_cdf_ugaussian_Pinv(cdf_generalized_poisson_P2(k,H[i]*Xi[0],Xi[1]));
+        if (*upper < -lmt) *upper = -lmt;
+        if (*upper > lmt) *upper = lmt;
+}
+
+//Returns c_{y-1}(gamma,H) (lower) and c_{y}(gamma,H) (upper) limits for ith predictive scenario,
+//given offsets H, value, scenario, rates, and two doubles where lower and upper limits are stored.
+void calcGLMLimitsPredL(double *H, int k, int i, double *Xi, double *lower, int family){
+        double lmt = 999.99;
+        if (k==0)
+            *lower = -lmt;
+        else{
+            if (family == 1) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_poisson_P(k-1,H[i]*Xi[0]));
+            else if (family == 2) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_binomial_P(k-1,Xi[0],(int) H[i]));
+            else if (family == 3) *lower = gsl_cdf_ugaussian_Pinv(gsl_cdf_negative_binomial_P(k-1,Xi[1]/(H[i]+Xi[1]),Xi[0]));
+            else if (family == 4) *lower = gsl_cdf_ugaussian_Pinv(cdf_beta_binomial_P(H[i],k-1,Xi[0],Xi[1]));
+            else if (family == 5) *lower = gsl_cdf_ugaussian_Pinv(cdf_generalized_poisson_P2(k-1,H[i]*Xi[0],Xi[1]));
+        }
+        if (*lower < -lmt) *lower = -lmt;
+        if (*lower > lmt) *lower = lmt;
+}
+
+//Returns c_{y-1}(gamma,H) (lower) and c_{y}(gamma,H) (upper) limits for ith predictive scenario,
+//given offsets H, value, scenario, rates, and two doubles where lower and upper limits are stored.
+void calcGLMLimitsPredU(double *H, int k, int i, double *Xi, double *upper, int family){
+        double lmt = 999.99;
+        if (family == 1) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_poisson_P(k,H[i]*Xi[0]));
+        else if (family == 2) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_binomial_P(k,Xi[0],(int) H[i]));
+        else if (family == 3) *upper = gsl_cdf_ugaussian_Pinv(gsl_cdf_negative_binomial_P(k,Xi[1]/(H[i]+Xi[1]),Xi[0]));
+        else if (family == 4) *upper = gsl_cdf_ugaussian_Pinv(cdf_beta_binomial_P(H[i],k,Xi[0],Xi[1]));
+        else if (family == 5) *upper = gsl_cdf_ugaussian_Pinv(cdf_generalized_poisson_P2(k,H[i]*Xi[0],Xi[1]));
         if (*upper < -lmt) *upper = -lmt;
         if (*upper > lmt) *upper = lmt;
 }
